from django.apps import AppConfig


class TMMISConfig(AppConfig):
    name = "tmmis"
